package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````P!X```````!``````````'BQ````
M`````````$``.``)`$``'``;``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0````````````````````````````````````R?````````#)\`````````
M`"````````$````&````N*L```````"XJR```````+BK(```````:`0`````
M``#P%```````````(````````@````8```#HJP```````.BK(```````Z*L@
M``````#@`0```````.`!````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M`````)@`````````F`````````"8````````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````+BK````````N*L@``````"XJR``
M`````$@$````````2`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50"2'!8,L?N+1K[0[Z.8X)`&D6,/K!$```!%````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!%````
M20```$T```!.````50```%8```!8````7````%T`````````7P```&(```!C
M````9```````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````)0$``!(`````
M````````````````````^P$``!(`````````````````````````>@(``!(`
M````````````````````````3P(``!(`````````````````````````$0``
M`"``````````````````````````@0(``!(`````````````````````````
M!@,``!(`````````````````````````R````!(`````````````````````
M````E@(``!(`````````````````````````EP$``!(`````````````````
M````````[@(``!(`````````````````````````Y@(``!(`````````````
M````````````F````!(`````````````````````````QP,``!(`````````
M````````````````(`$``!(`````````````````````````L@(``!(`````
M````````````````````I`(``!(`````````````````````````:0(``!(`
M````````````````````````_P(``!(`````````````````````````'`,`
M`!(`````````````````````````>P$``!(`````````````````````````
M20$``!(`````````````````````````U@```!(`````````````````````
M````Q0$``!(`````````````````````````*`(``!(`````````````````
M````````8`(``!(`````````````````````````.`(``!(`````````````
M````````````5P(``!(`````````````````````````L@$``!(`````````
M````````````````CP(``!(`````````````````````````]@$``!(`````
M````````````````````8`,``!(`````````````````````````60,``!(`
M````````````````````````5P$``!(`````````````````````````#P,`
M`!(`````````````````````````+0```"``````````````````````````
MQ@(``!(`````````````````````````>````!(`````````````````````
M````%`(``!(`````````````````````````O@$``!(`````````````````
M````````IP```!(`````````````````````````LP```!(`````````````
M````````````<`$``!(`````````````````````````-@$``!(`````````
M````````````````:@```!(`````````````````````````*@$``!(`````
M````````````````````S0(``!(`````````````````````````IP$``!(`
M````````````````````````!`$``!(`````````````````````````AP(`
M`!(`````````````````````````[P$``!(`````````````````````````
M2@,``!(`````````````````````````(P,``!(`````````````````````
M````B0$``!(`````````````````````````AP```!(`````````````````
M````````4@,``!(`````````````````````````G0(``!(`````````````
M````````````/````"``````````````````````````Z````!(`````````
M````````````````9P$``!(`````````````````````````VP(``!(`````
M````````````````````2@(``!(`````````````````````````#`(``!(`
M````````````````````````N`(``!(`````````````````````````4```
M`"``````````````````````````+0,``"(`````````````````````````
MJP(``!(`````````````````````````/`,``!(`````````````````````
M````T`,``!(`#0"@5@```````'8`````````G@,``!(`#@"T5P``````````
M````````]0,``!(`#0"`1@```````%0,````````;0,``!(`#0"0'```````
M`"0"````````I`,``!(`#0``/P````````4`````````8P0``!(`#0`0/P``
M``````D"````````700``!(`"@"(&@``````````````````D`0``!(`#0#@
M4@```````+D#````````@P,``!``&0`@L"``````````````````W`,``!(`
M#0`@00```````"0`````````#P0``!$`#P#`5P````````0`````````T`$`
M`!$`%0#0JR```````!,`````````CP,``!``&0"HP"``````````````````
M6P0``!(`#0"P/0```````#``````````<`0``!(`#0`010```````&P!````
M````@@0``!(`#0!@1````````'D``````````@0``!``&```L"``````````
M````````Z0,``!(`#0!000```````.,`````````<@,``!$`&0!(L"``````
M``@`````````?`,``!``&``@L"``````````````````<P,``"$`&0!(L"``
M``````@`````````1`0``!$`&``8L"````````@`````````^`(``!$`&0!@
ML"````````@`````````E`,``!(`#0"P5P````````(`````````-`0``!(`
M#0!`5P```````&4`````````"`0``!(`#0#`'@```````"L`````````!`0`
M`"``&```L"``````````````````%0$``!$`&0`@L"````````0`````````
M=`,``"$`&0!(L"````````@`````````M0,``!(`#0#@1````````"0`````
M````'@0``!(`#0`P/@```````,$`````````]P```!$`&0!`L"````````$`
M````````3@0``!(`#0!`0@```````!("`````````&QI8G!E<FPN<V\N-2XR
M-`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!0
M3%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E
M<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO
M<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?
M7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I
M<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`
M<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX
M<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI
M;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI
M>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U
M<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?
M<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!'3$E"0U\R+C(N-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#
M7S(N,RXR`$=,24)#7S(N-``````"``,``@`"`````@`"`````@````(``@``
M``(````"``(`!``"``(````````````#``(`!0`"`````@`#``(``@````8`
M```'`````P`"``````````````````8```````(``P`"``(```````(``@``
M```````"``(``P`&`````@`"``8``0`!``$``0`!``$``0`!``$``0`!````
M`0`!``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$`````
M``$``0#?`0``$````"````!U&FD)```#`*8$`````````0`%`"X"```0````
M`````)21E@8```<`L@0``!````!T&6D)```&`+T$```0````<AEI"0``!0#)
M!```$````!1I:0T```0`U00``!````!U&FD)```"`*8$````````N*L@````
M```(`````````,`?````````P*L@```````(`````````(`?````````"+`@
M```````(``````````BP(```````&+`@```````(``````````!;````````
MX*T@```````&`````0``````````````Z*T@```````&`````@``````````
M````\*T@```````&`````P``````````````^*T@```````&````!```````
M`````````*X@```````&````!0``````````````"*X@```````&````!@``
M````````````$*X@```````&````!P``````````````&*X@```````&````
M"```````````````(*X@```````&````"0``````````````**X@```````&
M````"@``````````````,*X@```````&````"P``````````````.*X@````
M```&````#```````````````0*X@```````&````#0``````````````2*X@
M```````&````#@``````````````4*X@```````&````#P``````````````
M6*X@```````&````$```````````````8*X@```````&````$0``````````
M````:*X@```````&````$@``````````````<*X@```````&````$P``````
M````````>*X@```````&````%```````````````@*X@```````&````%0``
M````````````B*X@```````&````%@``````````````D*X@```````&````
M%P``````````````F*X@```````&````&```````````````H*X@```````&
M````&0``````````````J*X@```````&````&@``````````````L*X@````
M```&````&P``````````````N*X@```````&````'```````````````P*X@
M```````&````'0``````````````R*X@```````&````'@``````````````
MT*X@```````&````'P``````````````V*X@```````&````(```````````
M````X*X@```````&````(0``````````````Z*X@```````&````(@``````
M````````\*X@```````&````(P``````````````^*X@```````&````)```
M`````````````*\@```````&````)0``````````````"*\@```````&````
M)@``````````````$*\@```````&````)P``````````````&*\@```````&
M````*```````````````(*\@```````&````*0``````````````**\@````
M```&````*@``````````````,*\@```````&````*P``````````````.*\@
M```````&````+```````````````0*\@```````&````+0``````````````
M2*\@```````&````+@``````````````4*\@```````&````+P``````````
M````6*\@```````&````,```````````````8*\@```````&````,0``````
M````````:*\@```````&````,@``````````````<*\@```````&````,P``
M````````````>*\@```````&````-```````````````@*\@```````&````
M-0``````````````B*\@```````&````-@``````````````D*\@```````&
M````-P``````````````F*\@```````&````.```````````````H*\@````
M```&````.0``````````````J*\@```````&````.@``````````````L*\@
M```````&````.P``````````````N*\@```````&````/```````````````
MP*\@```````&````/0``````````````R*\@```````&````/@``````````
M````T*\@```````&````/P``````````````V*\@```````&````0```````
M````````X*\@```````&````00``````````````Z*\@```````&````0@``
M````````````\*\@```````&````0P``````````````^*\@```````&````
M1```````````````T*L@```````%````4```````````````(+`@```````%
M````8```````````````0+`@```````%````9```````````````2+`@````
M```%````5P``````````````8+`@```````%````6P``````````````2(/L
M"$B+!664(`!(A<!T`O_02(/$",,`_S4JDR``_R4LDR``#Q]``/\E*I,@`&:0
M_R4JDR``9I#_)2J3(`!FD/\E*I,@`&:0_R4RDR``9I#_)3*3(`!FD/\E,I,@
M`&:0_R4RDR``9I#_)3J3(`!FD/\E.I,@`&:0_R4ZDR``9I#_)3J3(`!FD/\E
M.I,@`&:0_R4ZDR``9I#_)3J3(`!FD/\E.I,@`&:0_R4ZDR``9I#_)3J3(`!F
MD/\E.I,@`&:0_R4ZDR``9I#_)3J3(`!FD/\E.I,@`&:0_R4ZDR``9I#_)3J3
M(`!FD/\E.I,@`&:0_R4ZDR``9I#_)3J3(`!FD/\E.I,@`&:0_R4ZDR``9I#_
M)4*3(`!FD/\E0I,@`&:0_R5"DR``9I#_)4J3(`!FD/\E2I,@`&:0_R5*DR``
M9I#_)4J3(`!FD/\E2I,@`&:0_R5*DR``9I#_)4J3(`!FD/\E4I,@`&:0_R52
MDR``9I#_)5*3(`!FD/\E4I,@`&:0_R52DR``9I#_)5*3(`!FD/\E4I,@`&:0
M_R52DR``9I#_)5*3(`!FD/\E4I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E8I,@
M`&:0_R5BDR``9I#_)6*3(`!FD/\E8I,@`&:0_R5BDR``9I#_)6*3(`!FD/\E
M:I,@`&:0_R5JDR``9I#_)6J3(`!FD%532(/L.(E\)!Q(B70D$$B-?"0<2(E4
M)`A(C70D$$B-5"0(9$B+!"4H````2(E$)"@QP.CP_O__2(LU:9(@`$B+/;J2
M(`!(B?+H0CH``(`]6Y,@``!U+^AL_O__2(7`2(D%JJ,@``^$K@$``$B)Q^C\
M_?__BST6DR``Z+'^___&@*4(````BST$DR``Z)_^__^`B*($```"BSWRDB``
MZ(W^__^`B*($```!BT0D'(UX!4BX_________Q](8_](.<</AQD!``!(P><#
M2(T=6#P``.@9_O__2(M\)!!(B045HR``O@4```#'!0ZC(``$````2(L72(E8
M"$B-'2T\``!(@\<(2(E8&$B)$$B+%7:2(`!(B5`0BU0D'(/Z`8U*!'X<9@\?
M1```3(L/3&/&@\8!2(/'"#G.3HE,P/AUZDB+/<NB(`!(8\E(C34!(```2,=$
MR/@`````@\(#13'`2(G!Z`K^__^%P(G#=%%(BSV=HB``2(UL)"3H,_W__TB-
M/4\Z```QP$B)[N@B&0``2(7`=#I(BSUVHB``Z.'\___HM/W__XG82(M<)"AD
M2#,<)2@```!U7TB#Q#A;7<-(BSU,HB``Z/?]__^)P^N?2(L]-*(@`$B%_W0<
MZ#(X``#KLTB--5F-(`!(C3V5.0``,<#H4_W__TB-/8PY``!(B>[HK!@``$B%
MP$B)QTB)!?>A(`!T@.O$Z'[\__^_`0```.BL_?__9BX/'X0``````&:0,>U)
MB=%>2(GB2(/D\%!43(T%VC@``$B-#6,X``!(C3VL_?___Q7NCR``]`\?1```
M2(T]*9$@`$B-!2F1(`!52"GX2(GE2(/X#G852(L%[HX@`$B%P'0)7?_@9@\?
M1```7<,/'T``9BX/'X0``````$B-/>F0(`!(C37BD"``54@I_DB)Y4C!_@-(
MB?!(P>@_2`'&2-'^=!A(BP6!D"``2(7`=`Q=_^!F#Q^$``````!=PP\?0`!F
M+@\?A```````@#WAD"```'4G2(,]5Y`@``!52(GE=`Q(BSUJD"``Z-7\___H
M2/___UW&!;B0(``!\\,/'T``9BX/'X0``````$B-/0&,(`!(@S\`=0OI7O__
M_V8/'T0``$B+!<F/(`!(A<!TZ55(B>7_T%WI0/___T%7059,C4\X055!5#')
M55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X@\?`$&+!`E-BP0)#\A,
MB<:)P$C![B!(B01*3(G`2<'H.$C!Z"@E`/\``$P)P$F)\$C!Y@A)P>`8@>8`
M`/\`18G`3`G`2`GP2(E$2@A(@\$(2(/Y0'6M2(VR``(``&8/'T0``$B+0FA(
M,T)`2(/""$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,BP=,BU\@
M3(M/$$R+5QA(BW<(2(M,)`A,B<!,B<)-B<5(P>H;2,'@!4G![0)("=!(BQ0D
M2(GSB<!(P>,>28V,"IEY@EI)C903F7F"6D@!T$R)RDPQTD@A\DPQTD@!PDB)
M\$C!Z`)!B=1("<-,B<A,B>6)VTC![1M(,=A,(<!,,<A(`<A,B>%(P>$%2`GI
MB<E(`<A,B<%(P>$>B<5,">E-B>5)B>Z)R4GWU4G![AM)(=U((<I,">I,BVPD
M$$^-K"F9>8):3`'J28GM2<'E!4T)]46)[4P!ZDV)Y4G![`))P>4>08G630GL
M18GE28GL2??43"'H22',3`G@3(MD)!A*C9PCF7F"6DV)]$G![!M(`=A,B?-(
MP>,%3`GCB=M(`=A(B>M(P>T"2,'C'D&)Q$@)W8GK3(GU2/?52"':3"'M2`GJ
M2(ML)"!(C8PIF7F"6DR)Y4C![1M(`<I,B>%(P>$%2`GIB<E(`<I,B?%)P>X"
M2,'A'HG520G.1(GQ38GF2??62"'(22'>3`GP3(MT)"A/C:PUF7F"6DF)[DG!
M[AM,`>A)B>U)P>4%30GU18GM3`'H38GE2<'E'DG![`)!B<9-">Q%B>5)B>Q)
M]]1,(>I)(<Q,">),BV0D,$J-G".9>8):38GT2<'L&T@!VDR)\TC!XP5,">.)
MVT@!VDB)ZTC![0)(P>,>08G42`G=B>M,B?5(]]5((=A,(>U(">A(BVPD.$B-
MC"F9>8):3(GE2,'M&T@!R$R)X4C!X05(">F)R4@!R$R)\4G![@)(P>$>B<5)
M"<Y$B?%-B>9)]]9((<I)(=Y,"?),BW0D0$^-K#69>8):28GN2<'N&TP!ZDF)
M[4G!Y05-"?5%B>U,`>I-B>5)P>4>2<'L`D&)UDT)[$6)Y4F)[$GWU$PAZ$DA
MS$P)X$R+9"1(2HV<(YEY@EI-B?1)P>P;2`'83(GS2,'C!4P)XXG;2`'82(GK
M2,'M`DC!XQY!B<1("=V)ZTR)]4CWU4@AVDPA[4@)ZDB+;"102(V,*9EY@EI,
MB>5(P>T;2`'*3(GA2,'A!4@)Z8G)2`'*3(GQ2<'N`DC!X1Z)U4D)SD2)\4V)
MYDGWUD@AR$DAWDP)\$R+="183XVL-9EY@EI)B>Y)P>X;3`'H28GM2<'E!4T)
M]46)[4P!Z$V)Y4G![`))P>4>08G&30GL18GE28GL2??43"'J22',3`GB3(MD
M)&!*C9PCF7F"6DV)]$G![!M(`=I,B?-(P>,%3`GCB=M(`=I(B>M(P>T"2,'C
M'D&)U$@)W8GK3(GU2/?52"'83"'M2`GH2(ML)&A(C8PIF7F"6DR)Y4C![1M(
M`<A,B>%(P>$%2`GI3(GU2<'N`DC!Y1Z)R4D)[D@!R$2)]4V)YHG!2??62"'J
M22'>3`GR3(MT)'!/C:PUF7F"6DF)SDG![AM,`>I)B<U)P>4%30GU18GM3`'J
M38GE2<'L`DG!Y1Y!B==-">Q%B>5)B<Q)]]1,(>A)(>Q,">!,BV0D>$J-G".9
M>8):38G\2<'L&T@!V$R)^TC!XP5,">.)VT@!V$B)RTC!Z0)(P>,>08G$2`G9
MB<M,B?E(]]%((=I,(>E("<I(BXPD@````$B-C`V9>8):3(GE2,'M&T@!T4R)
MXDC!X@5(">I,B?U)P>\"2,'E'HG22`'120GO3(GB1(G]2/?208G.2"':2"'H
M2`G02(N4)(@```!)C905F7F"6DV)]4@!T$R)\DC!X@5)P>T;3`GJ38GE2<'L
M`DG!Y1Z)TDT)[$@!T$B+E"20````18GE38GT08G'2??43"'I22'L3`GA3(VD
M$YEY@EI,B?I(P>(%20',3(GY2,'I&T@)RHG220'43(GR2<'N`DC!XAY$B>-,
M"?)-B?Z)T4GWUDTA[D@AR$P)\$R+M"28````2HVL-9EY@EI)B=Y)P>X;2`'H
M2(G=2,'E!4P)]8GM2`'H3(G]2<'O`DC!Y1Y!B<9,"?U(,>I!,=1(BY0DH```
M`$F-E!6AZ]EN38GU3`'B38GT2<'D!4G![1M-">Q%B>1,`>))B=Q(P>L"2<'D
M'D&)U4D)W$B)ZXGM3#'C2`.L)+`````QV$B+G"2H````2(V<&:'KV6Y,B>E(
MP>D;2`'#3(GH2,'@!4@)R(G`2`'#3(GP2<'N`DC!X!Z)V4P)\$V)YD6)Y$DQ
MQDP#I"2X````1#'R3(V\%:'KV6Y(B<I(B<U(P>T;2,'B!4@)ZDR)[4G![0)(
MP>4>B=),">U)B<5)`==),>U$B?J)P$0QZTV-K!RAZ]EN2(G328G42<'L&TC!
MXP5,">.)VTD!W4B)RT@#A"3`````2,'I`DC!XQY%B>Y("<M(B>E-B?1(,=E)
MP>P;03'/2HV,.*'KV6Y,B?!(P>`%3`G@B<!(`<A(B=%(P>H"2,'A'D&)Q$@)
MT8GJ2`.4),@```!(B=V)VT@#G"30````2#'-03'M2HVL*J'KV6Y,B>)-B>5)
MP>T;2,'B!4P)ZHG22`'53(GR2<'N`DC!XAY!B>U,"?))B<Z)R4DQUD0Q\$V)
M[DB-G`.AZ]EN3(GH2<'N&TC!X`5,"?")P$@!PTR)X$C!X!Y)P>P"2`.,)-@`
M``!,">!)B=1!B=Y),<2)TD@#E"3@````1#'E38GT2(VL*:'KV6Y,B?%)P>P;
M2,'A!4P)X8G)2`'I3(GM2<'M`DC!Y1Y!B<Q,">U)B<6)P$DQ[4@#A"3H````
M1#'K38GE2(V<&J'KV6Y,B>))P>T;2,'B!4P)ZHG22`':3(GS2<'N`DC!XQY!
MB=5,"?-)B>Z)[4DQWD0Q\4V)[DB-C`BAZ]EN3(GH2<'N&TC!X`5,"?")P$@!
MR$R)X4G![`)(P>$>08G&3`GA2`.L)/````!)B=Q),<R)VT@#G"3X````1#'B
M38GT2<'L&TB-K!6AZ]EN3(GR2,'B!4P)XHG22`'53(GJ2<'M`DC!XAY!B>Q,
M">I)B<V)R4DQU4@#C"0``0``1#'H38GE2(V<`Z'KV6Y,B>!)P>T;2,'@!4P)
MZ(G`2`'#3(GP2<'N`DC!X!Y!B=U,"?!)B=:)TDDQQD@#E"0(`0``1#'U38GN
M2(VL*:'KV6Y,B>E)P>X;2,'A!4P)\8G)2`'I3(GE2<'L`DC!Y1Y!B<Y,">5)
MB<2)P$DQ[$0QXTV)]$@#A"00`0``2(V<&J'KV6Y,B?))P>P;2,'B!4P)XHG2
M2`':3(GK2<'M`DC!XQY!B=1,">M)B>V)[4DQW4@#K"08`0``1#'I38GE2(V,
M"*'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(GQ2<'N`DC!X1Y!B<5,"?%)B=Z)
MVTDQSD@#G"0@`0``1#'R3(VT%:'KV6Y,B>I,B>U(P>T;2,'B!4@)ZHG220'6
M3(GB2<'L`DC!XAY$B?5,">))B<R)R4DQU$0QX$F)[$B-G`.AZ]EN2(GH2,'@
M!4G![!M(`XPD*`$``$P)X(G`2`'#3(GH2<'M`DC!X!Y!B=Q,">A)B=6)TDDQ
MQ4@#E"0P`0``13'N3HVL,:'KV6Y,B>%-B>9)P>X;2,'A!4P)\8G)20'-2(GI
M2,'M`DC!X1Y%B>](">E(B<6)P$@QS4@#A"0X`0``,>M,B?U(C9P:H>O9;DR)
M^DC![1M(P>(%2`GJ3(GE2<'L`DC!Y1Z)TDP)Y4F)S$@!VDDQ[(G3B<E%,>5)
MB=Q.C;0HH>O9;DB)V$G![!M(P>`%3`G@38G\B<!)`<9)P>\"2<'D'DT)_$B)
MZ$6)]4P)X$@APDB)Z(GM3"'@"<*XW+P;CTF)QTP#O"1``0``3`'Y38GO2`'*
M3(GI2<'O&TC!X05,"?F)R4@!RDB)V4C!ZP)(P>$>08G72`G93(GC2`G+22'>
M3(GC18GD2"'+00G>2(G#2`.<)$@!``!(`=U,B?M)`>Y,B?U(P>,%2,'M&T@)
MZXG;28TL'DR)ZTG![0)(P>,>3`GK28G-08GN20G=3"'J28G-B<E)(=U$">I)
MB<5,`ZPD4`$``$T![$V)]4D!U$R)\DG![1M(P>(%3`GJB=)-C2P43(GZ2<'O
M`DC!XAY,"?I)B=]%B>Q)"==,(?U)B=^)VTDAUT0)_4F)QTP#O"18`0``3`'Y
M38GG2`'-3(GA2<'O&TC!X05,"?F)R4R-?`T`3(GQ2<'N`DC!X1Y,"?%)B=9$
MB?U)"<Y-(?5)B=:)TDDASD4)]4F)QDP#M"1@`0``3`'S38UT'0!(B>M)B>U(
MP>,%2<'M&TP)ZXG;38TL'DR)XTG![`)(P>,>20G<2(G+18GN3`GC22'?2(G+
MB<E,(>-!"=](B<-(`YPD:`$``$@!VDR)\TD!UTR)\DC!ZQM(P>(%2`G:B=))
MC1P72(GJ2,'M`DC!XAY("=5,B>)!B=](">I)(=5,B>)%B>1((>I!"=5(B<)(
M`Y0D<`$``$@!T4R)^DP!Z4V)_4C!X@5)P>T;3`GJB=),C2P13(GR2<'N`DC!
MXAY,"?))B>Y$B>E)"=9,(?-)B>Z)[4DAUD0)\TF)QDP#M"1X`0``30'T28G.
M20'<2(G+2<'N&TC!XP5,"?.)VTV--!Q,B?M)P>\"2,'C'DP)^TF)UT6)]$D)
MWTTA_4F)UXG222'?10G]28G'3`.\)(`!``!,`?U-C7PM`$R)Y4V)Y4G![1M(
MP>4%3`GMB>U-C2PO2(G-2,'I`DC!Y1Y(">E(B=U%B>]("<U)(>Y(B=V)VT@A
MS4$)[DB)Q4@#K"2(`0``2`'J3(G]20'63(GZ2,'B!4C![1M(">J)TDF-+!9,
MB>))P>P"2,'B'DD)U$B)RD&)[DP)XDDAU4B)RHG)3"'B00G52(G"2`.4))`!
M``!(`=-,B?),`>M-B?5(P>(%2<'M&TP)ZHG23(TL$TR)^DG![P)(P>(>3`GZ
M38GG1(GK20G73"']38GG18GD22'71`G]28G'3`.\))@!``!,`?E)B=](`<U(
MB=E)P>\;2,'A!4P)^8G)3(U\#0!,B?5)P>X"2,'E'DP)]4F)UD2)^4D)[DTA
M]4F)UHG222'N10GU28G&3`.T)*`!``!-`?1)B<Y-`>5)B<Q)P>X;2<'D!4T)
M]$6)Y$^-="4`28G<2,'K`DG!Y!Y,">-)B>Q%B?5)"=Q-(>=)B>R)[4DAW$4)
MYTF)Q$P#I"2H`0``3`'B38GL20'73(GJ2<'L&TC!X@5,">*)TDV-)!=(B<I(
MP>D"2,'B'D@)T4B)VD6)YT@)RDDAUDB)VHG;2"'*00G62(G"2`.4)+`!``!(
M`=5,B?I)`>Y,B?U(P>(%2,'M&T@)ZHG228TL%DR)ZDG![0)(P>(>3`GJ28G-
M08GN20G532'L28G-B<E)(=5%">Q)B<5,`ZPDN`$``$P!ZTV)]4D!W$R)\TG!
M[1M(P>,%3`GKB=M,`>--B?Q)P>\"2<'D'D&)W4T)_$F)UTT)YTPA_4F)UXG2
M32'G1`G]28G'3`.\),`!``!,`?E,C7P-`$R)Z4R)[4C![1M(P>$%2`GIB<E)
MC2P/3(GQ2<'N`DC!X1Y)"<Y,B>%!B>],"?%((<M,B>%%B>1,(?$)RTB)P4@#
MC"3(`0``2`'*2(T,$TR)^DR)^TC!ZQM(P>(%2`G:B=)(C1P13(GI2<'M`DC!
MX1Y,">E-B?6)VDD)S4PA[4V)]46)]DDAS40)[4F)Q4P#K"30`0``2`.$)-@!
M``!-`>Q.C6PE`$B)U4F)U$G![!M(P>4%3`'P3`GEB>U-C60M`$R)_4G![P)(
MP>4>3`G]28G/18GE20GO38GN3"'[28G/B<E)(>]$"?M(`=A,B>M(P>,%2<'N
M&TP)\XG;2`'82(G32,'J`DC!XQY!B<9("=.ZUL%BRDF)UTP#O"3@`0``20'/
M2(GIB>U(,=E!,<Q+C0PG38GT38GW2<'O&TG!Y`5-"?Q%B>1,`>%-B>Q)P>T"
M2<'D'D&)STT)[$F)U4P#K"3H`0``3`'M28G=B=M-,>5$,>A-B?U(`>A,B?U)
MP>T;2,'E!4P)[8GM2`'H3(GU2<'N`DC!Y1Y!B<5,"?5)B=9,`[0D\`$``$P!
M\TV)YD6)Y$DQ[D0Q\4V)[D@!V4R)ZTG![AM(P>,%3`GSB=M(`=E,B?M)P>\"
M2,'C'D&)SDP)^TF)UTP#O"3X`0``30'\28GOB>U),=]$,?A-B?=,`>!-B?1)
MP>\;2<'D!4T)_$6)Y$P!X$V)[$G![0))P>0>08G'30GL28G53`.L)``"``!,
M`>U)B=V)VTTQY40QZ4V)_4@!Z4R)_4G![1M(P>4%3`GMB>U(`>E,B?5)P>X"
M2,'E'D&)S4P)]4F)UDP#M"0(`@``3`'S38GF18GD23'N1#'P38GN2`'83(GK
M2<'N&TC!XP5,"?.)VT@!V$R)^TG![P)(P>,>08G&3`G[28G73`.\)!`"``!-
M`?Q)B>^)[4DQWT0Q^4V)]TP!X4V)]$G![QM)P>0%30G\18GD3`'A38GL2<'M
M`DG!Y!Y!B<]-">Q)B=5,`ZPD&`(``$P![4F)W8G;33'E1#'H38G]2`'H3(G]
M2<'M&TC!Y05,">V)[4@!Z$R)]4G![@)(P>4>08G%3`GU28G63`.T)"`"``!,
M`?--B>9%B>1),>Y$,?%-B>Y(`=E,B>M)P>X;2,'C!4P)\XG;2`'93(G[2<'O
M`DC!XQY!B<Y,"?M)B==,`[PD*`(``$T!_$F)[XGM23'?1#'X38GW3`'@38GT
M2<'O&TG!Y`5-"?Q%B>1,`>!-B>Q)P>T"2<'D'D&)QTT)[$F)U4P#K"0P`@``
M3`'M28G=B=M-,>5$,>E-B?U(`>E,B?U)P>T;2,'E!4P)[8GM2`'I3(GU2<'N
M`DC!Y1Y!B<U,"?5)B=9,`[0D.`(``$P!\TV)YD6)Y$DQ[D0Q\$V)[D@!V$R)
MZTG![AM(P>,%3`GSB=M(`=A,B?M)P>\"2,'C'D&)QDP)^TF)UTP#O"1``@``
M30'\28GOB>U),=]$,?E-B?=,`>%-B?1)P>\;2<'D!4T)_$6)Y$P!X4V)[$G!
M[0))P>0>08G/30GL28G53`.L)$@"``!,`>U)B=V)VTTQY40QZ$V)_4@!Z$R)
M_4G![1M(P>4%3`GMB>U(`>A,B?5)P>X"2,'E'D&)Q4P)]4F)UDP#M"10`@``
M3`'S38GF18GD23'N1#'Q38GN2`'93(GK2<'N&TC!XP5,"?.)VT@!V4R)^TG!
M[P)(P>,>08G.3`G[28G73`.\)%@"``!-`?Q)B>^)[4DQWT0Q^$V)]TP!X$V)
M]$G![QM)P>0%30G\18GD3`'@38GL2<'M`DG!Y!Y!B<=-">Q)B=5,`ZPD8`(`
M`$P![4F)W8G;33'E1#'I38G]2`'I3(G]2<'M&TC!Y05,">U-B?5)P>X"2<'E
M'HGM30GU28G63`.T)&@"``!(`>F)S4P!\TV)YD6)Y$TQ[D0Q\$F)[D@!V$B)
MZTG![AM(P>,%3`GSB=M(`=A,B?M)P>\"2,'C'D&)QDP)^TF)UTP#O"1P`@``
M30'\38GO18GM23'?1#'Y38GW2`.4)'@"``!)`<Q,B?%)P>\;2,'A!4$!VTP)
M^4R)7R!!`<Q(B>E(P>T"2,'A'DP!ZDF)W4@)Z4R)]4G![@)),<U(P>4>1`'F
M1#'H38GE3`GU2`'03(GB2<'M&TC!X@5!`>E$`=%,">I(B7<(3(E/$`'02(E/
M&$$!P$B+A"2(`@``9$@S!"4H````3(D'=1)(@<28`@``6UU!7$%=05Y!7\/H
M\N/__V8N#Q^$``````!!5T%6055!5%532(/L"$B%_P^$HP```$R+/>IX(`!-
MA?\/A),````/M@>$P'1R/#UT;DF)_$F#Q`%!#[8$)(3`=`0\/77O02G\28L?
M2(7;=#5)B?5)B?Y-8^1,B?T/'P!,B>),B?9(B=_H&N/__X7`=0="@#PC/70O
M2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````13'DZZ0/
M'P!,*?U*C5PC`4C!_0-!B6T`Z\PQV^O(9I!54TB)_4B#[!AD2(L$)2@```!(
MB40D"#'`2(U<)`1FD#'`2(G>2(GOZ!/___](A<!T,$AC5"0$2(L%"G@@`$B-
M!-!(BU`(2(722(D0=-)FD$B#P`A(BU`(2(722(D0=?#KODB+1"0(9$@S!"4H
M````=0=(@\086UW#Z*KB__]FD$%7059!54%455-(B?-(B?U(@^PH9$B+!"4H
M````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z&GB__](C70D%$F)Q$B)[S'`Z'?^
M__](A<`/A`X!``!(B<=)B<7H0^+__TDYQ`^&X@```$QC="042<'F`P^V10"$
MP`^$JP$``#P]#X2C`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V$(32=?!(
M*>A(F$P#-1QW(`!*C7P@`NB2XO__2(7`28D&#X1X`0``2&-4)!1(BP7Z=B``
M2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(@\$!#[9!
M_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`2(MT)!AD
M2#,T)2@````/A0X!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#_TF#Q0&$
MP$&(1?]U[.O"9I!,BSUA=B``28,_``^$O````$R)^#'2ZPL/'X0``````$2)
MZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%7X8@`(7`=#M,B?_HX^'__TB%
MP$B)!1%V(``/A'T```!-8\5(B<%.C33%`````$K'1,$(`````$2);"04Z9'^
M__]FD$B)]\<%$X8@``$```#H5N'__TB%P'1#36/%3(G^2(G'3HTTQ0````!,
MB40D"$R)\NB+X?__3(M$)`A(B<%(B06D=2``ZZ4QP.EX_O__OA````!%,>WI
M8?___[C_____Z=[^___H7^#__P\?@`````!!5D%505154TB![*````!D2(L$
M)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@S!"4H````
M#X4Q`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HP]___TB%P$F)Q'3"
M28GE3(GGZ.#@__](A<!(B<-T-0^V4Q.X+@```(G!*=%U00^V4Q2%TG39*=`/
MA,$```#WV(7`=2],B>?HJ^#__TB%P$B)PW7+3(GGZ-O?__](B>_H@]___^EE
M____9@\?1```A<ETG$B#PQ-(B>_H<-___TB)WTF)QNAEW___08U\!@)(8__H
M`.#__TB-#?4;``!)B<9(B<=)B=E)B>A(Q\+_____O@$````QP.B:X/__OP$`
M``!,B>I,B?;H\M[__X/X_TR)]W00BT0D&"4`\```/0!```!T*NBEWO__3(GW
MZ(W>___I&/___P\?A```````#[9#%>DX____#Q^``````.B+_O__Z]3HW-[_
M_P\?0`!32(G[BSW&<R``Z&'?__](C9#X`0``2(G>OP$```#HY=___X7`=`DQ
MP%O##Q]$``"+/9IS(`#H-=___XN`$`(``"4`\```/0!```!T'8L]?7,@`.@8
MW___BX`0`@``)0#P```]`*```'6]2(G?O@(```#H<=___X7`#Y3`#[;`6\,/
M'T0``&8N#Q^$``````!!54%428G\55-(C3W:&@``28GUNO\/``!(@>P8$```
M2(GF9$B+!"4H````2(F$)`@0```QP.B^W?__A<!^<HU0_TB)XTACZH`\+`!T
M6TACZ$B)ZKXO````2(G?Z$C>__](A<!T2XL]U7(@`.APWO__2(GI2(G:3(GF
M2(G'Z.?>__](BX0D"!```&1(,P0E*````'4W2('$&!```%M=05Q!7<-F#Q]$
M``"%TG6D#Q]``(L]BG(@`.@EWO__3(GJ3(GF2(G'Z)_=___KMNAXW?__2(/L
M"(L]9G(@`.@!WO__2(L58G`@`$B-#1L<``!(C34%&@``2(G'2(/$".D`WO__
M2(/L"(L]-G(@`.C1W?__2(G'Z+G___^+/2-R(`#HOMW__TR-!9`;``!(C170
M%```2(TUWAD``$4QR4B)QTB#Q`A,B<'IW]W__P\?@`````!54TB!["@@``!D
M2(L$)2@```!(B80D&"```#'`Z)?<__],C0U]&0``2(T-JQD``$&)P+H!$```
M,<"^`0```$B)Y^@2WO__A<!X;DB-K"00$```N@`0``!(B>=(B>[H1MS__X7`
M2(G#>$^->`%(8__H)-W__TB%P$B)P7082&/;2(GN2(G'2(G:Z//<__](B<'&
M!!@`2(N4)!@@``!D2#,4)2@```!(B<AU$DB!Q"@@``!;7<,/'T``,<GKV.@W
MW/__#Q]$``!F+@\?A```````Z2O___^09BX/'X0``````$%7059!54%428GT
M55-(B?M(C3WQ&```2('L*!```&1(BP0E*````$B)A"08$```,<!(C70D#.CU
M]___OB\```!(B=](B<7HW=O__TB%P'0]2(T]NA@``$B)WC'`Z`_Y__](B=A(
MBXPD&!```&1(,PPE*`````^%B0$``$B!Q"@0``!;74%<05U!7D%?PTB)W^A[
MV___2(TU@A@``$R)YT&)QNB)W/__2(7`28G'=*%!@\8!08`_`$R-+6`8``!,
MC60D$`^$Y0````\?@`````!(A>UT$TR)_DB)[^BHV___A<`/A*8```!,B?_H
M(-O__XG"2)A!@'P'_R]U%P\?0`"#Z@%(8\)!@'P'_R]!Q@0'`'3M1`'R@?K_
M#P``#X\N____2(/L"$B-#1(9``!,C0WL%P``4TV)^+H`$```O@$```!,B><Q
MP.@LW/__BSV^;R``Z%G;__](C9#X`0``3(GFOP$```#H==K__X7`6EEU'8L]
MF6\@`.@TV___BX`0`@``)0#P```]`(```'1),?],B>[HF-O__TB%P$F)QP^$
MK/[__T&`/P`/A2+___](A>UT$TB-/4P7``"Y`@```$B)[O.F=,A,C3TY%P``
MN@$```#I//___[X!````3(GGZ$3;__^%P'6F2(T](A<``$R)YNAY]___3(GG
MZ&G:___I8/[__^@/VO__#Q^```````^V#TB)^(3)=!A(C5<!9I"`^2\/M@I(
M#T3"2(/"`83)=>[SPV:09BX/'X0``````%532(/L"$B%_W15#[8O2(G[0(3M
M=$KHM=G__TB-5`/_2#G3<A3K)V8/'X0``````$B#Z@%(.=-T'X`Z+W3RZP6`
M.B]T0$B#Z@%(.=-R\D@YTW4R#Q]$``!`@/TO=7-FD+\"````Z`[:__](A<!T
M6;HN````9HD02(/$"%M=PV:0@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`$```
M=RM(C3V,;B``2(G>2(/"`;D`$```Z//9__](@\0(2(T%<&X@`%M=PP\?1```
M2(/$"#'`6UW#2(/$"$B-/006``!;7>E%V?__#Q\`9BX/'X0``````%-(C3WJ
M%0``2(/L0&1(BP0E*````$B)1"0X,<!(BP5=%P``2(U<)`Q(B40D$$B+!507
M``!(B40D&$B+!5`7``!(B40D($B+!4P7``!(B40D*`^W!4@7``!FB40D,#'`
MZ%SU__](C3V0%0``,<#H3O7__TB-/8H5```QP.A`]?__2(T]A14``#'`Z#+U
M__](C3U^%0``,<#H)/7__TB-/8`5```QP.@6]?__2(T])Q4``#'`Z`CU__](
MC3UP%0``,<#H^O3__TB-/6P5```QP.CL]/__2(T]:!4``#'`Z-[T__](C3WX
M%```,<#HT/3__TB-/585```QP.C"]/__2(T]414``#'`Z+3T__](C3U.%0``
M,<!(B=[HX_/__TB%P'012(T]$!4``$B)QC'`Z`WU__](C3TX%0``,<!(B=[H
MO//__TB%P'012(T]-!4``$B)QC'`Z.;T__](C3TN%0``,<!(B=[HE?/__TB%
MP'1`2(T]810``$B)QC'`Z+_T__](C34S%0``2(T]A!0``#'`Z*KT__](BT0D
M.&1(,P0E*````'5G2(/$0%O##Q]``$B-/>@4```QP$B)WN@_\___2(7`=!I(
MC3UB%```2(G&,<#H:?3__^NH#Q^``````$B-="0A2(T]Q!0``+D*````\Z9U
MC$B-="0K2(T]+A0``#'`Z#CT___I=/___^C6UO__#Q]``&8N#Q^$``````!(
M@^P89$B+!"4H````2(E$)`@QP(L%EFL@`(/X_W092(M,)`AD2#,,)2@```!U
M14B#Q!C##Q]``$B-="0$2(T]RQ,``#'`Z)7R__](A<!T(`^V$(#Z,`^5P(32
M#Y7"(=`/ML")!4=K(`#KM`\?1```,<#K[.A/UO__#Q^``````$B#[`CH1];_
M_XG'Z!C6__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%7059!
M54%428G]55-(C2WC$P``2(T=TA,``$B#[&AD2(L$)2@```!(B40D6#'`2(T%
MQ!,``$B);"0@2(E<)"A(QT0D4`````!,C60D($R-="0<2(E$)#!(C061$P``
M2(E$)#A(C06*$P``2(E$)$!(C060$P``2(E$)$CK(&:02(G'Z.C6__](A<!T
M:TF#Q`A(A=MT.$B)W4F+7"0(3(GV,<!(B>_HA?'__TB%P$F)QTR)[G0%@#@`
M=<4QP$B)[TF#Q`CHI_+__TB%VW7(2(M$)%AD2#,$)2@````/A84```!(@\1H
M6UU!7$%=05Y!7\,/'X``````3(GOZ!#5__],B?](B40D".@#U?__2(M,)`A(
MC7P!`NB<U?__2(/L"$R-#?<1``!(C0T1$P``05=(Q\+_____2(G'38GHO@$`
M``!(B40D&#'`Z"K6__],BU0D&$B)[S'`3(G6Z!#R__]86NDF____Z*S4__\/
M'T``05=!5D%5051)B?U54TB-/801``!(@>R(@0``9$B+!"4H````2(F$)'B!
M```QP$B-!7D2``!,C60D+$C'1"1``````$C'A"28`````````$C'1"1@````
M`$B)1"0P2(T%,A$``$R)YDB)1"0X2(T%T1$``$B)1"1P2(T%OA$``$B)1"1X
M2(T%*!(``$B)A"2`````2(T%P!$``$B)A"2(````2(T%$A(``$B)A"20````
M2(T%ZA$``$B)1"102(T%^Q$``$B)1"18,<#H\.___TB%P'0)@#@`#X5B!```
M,<#H>_W__TB%P$B)PP^$;P0``$B)W^BGT___2(U\``'H1=3__X`[`$F)QG0W
M3(T]MA$``$R)]0\?`$0/M@-(B>\QP$R)^4C'PO____^^`0```$B#PP%(@\4"
MZ,O4__^`.P!UUDB-;"1P2(T]]A```.L-2(/%"$B+?0!(A?]T,S'`3(GFZ%GO
M__](A<!(B<-TX8`X`'3<2(G'Z%3T__^%P'302(G?Z'#3__](A<!)B<=U4$B+
M7"0P,>WK&P\?@`````"#Q0%(8\5(BUS$,$B%VP^$3`$``(`[``^$0P$``$B)
MW^@+]/__A<!TUTB)W^@GT___2(7`28G'=,</'X``````3(G_Z+C2__],B?&+
M,4B#P02-EO_^_O[WUB'R@>*`@("`=.B)UL'N$/?"@(````]$UDB-<0)(#T3.
MB=9``-9(@]D#3"GQC9P(!`0``$ACVTB)W^@1T___2(G%2(T%E1```$%63(T-
M9@\``$B-#7P0``!-B?A02,?"_____[X!````2(GO,<#HG=/__[[``0``2(GO
MZ-C1__^#^/]!6$%9#X2+````BST59R``Z+#2__](C9#X`0``2(GNOP$```#H
M--/__X7`08G&#X2A````28M-`$B+/29G(`!(C17W$```28GHO@$````QP#';
MZ![3__](BXPD>($``&1(,PPE*````$B)V`^%8PD``$B!Q(B!``!;74%<05U!
M7D%?PV:013'_Z=C^__\/'X0``````.@CT?__1(L(08/Y$0^$8____TF+30!(
MBSVS9B``2(T51!```$F)Z+X!````,<`QV^BKTO__ZXMF#Q^$``````"+/4IF
M(`#HY='__XN`$`(``"4`\```/0!````/A3[___^+/2EF(`#HQ-'__T2+N!0"
M``#H*-'__T$YQP^%'O___XL]"68@`.BDT?__BX`0`@``)?\!```]P`$```^%
M_?[__TB)W^B.T?__2(T]OPX``$B)PTR)YC'`Z/+L__](A<`/A/$!``!(B<?H
M&='__TF+?0!(B<;HI?3__TB%P$F)Q`^$T0$``$R)Y^BAT/__@_@#?CQ(8]!(
MC3W-#@``N04```!)C704_/.F=22#^`0/A-<&``"#Z`1(F$&`?`3_+P^$Q@8`
M`&8N#Q^$```````QP.B9^?__A<!U%3'V3(GGZ$/1__^%P(D$)`^%<0$``$B-
M-10.``!(C3V!#0``3(TEI`X``#'`3(TM,@T``.A][?__Z.#/__]!5$R-#1\-
M``!02(T-6PX``$C'PO____])B>B^`0```$B)WS'`Z%;1__]86NM-9BX/'X0`
M`````.ASS___@S@1=4OHF<___T&#Q@%(@^P(2(T-)`X``$%4059-B>E028GH
M2,?"_____[X!````2(G?,<#H"='__TB#Q""^P`$``$B)W^A`S___@_C_=*M(
MB>_H$\___TB-/70,``!(B=XQP.C2[/__2(G?Z%KY___IE_W__P\?1```2(G'
M2(D$).A$^?__2(L$)$B)Q^B@S___2(G#Z7+]__^]`0```$B-/38-``#K$F:0
M2&/%@\4!2(M\Q%!(A?]T*3'`3(GFZ#;K__](A<!TX8`X`'3<2(G'Z%S/__](
MA<!(B<-TS.E(^___OPT```!(C1WR#```Z([/__])B<;I2?O__V8/'T0``$V+
M90#I)O[__TR-M"1P`0``N@(```!(Q\;N____08G'B<?H^<___[H&````3(GV
M1(G_Z!'/__^`O"1P`0```'4.@+PD<0$``$,/A*8%``"+/"0QTC'V3(VL)*``
M``#HO<___[B)J\WO2,>$)*`````!(T5G2,>$)+@```!V5#(02(F$)*@```"X
M_MRZF$C'A"3(`````````$B)A"2P````N/#ATL-(QX0DT`````````!(B80D
MP````$F-13C'A"08`0```````$B)1"009BX/'X0``````(L\)+H`@```3(GV
MZ&#.__^%P$F)Q$&)P`^.LP$``$B+M"3(````26/$C13&2#G6#X>+`0``2(NT
M)-````!(P>@=2(F4),@```!(`?!(B80DT````$ACA"08`0``A<`/A$P!``!!
MN$````!(BU0D$$R)]D$IP$4YQ$4/3L1(C3P"26/(2(G*28G/2(E,)`CH_<W_
M_XN$)!@!``!$`?B#^$")A"08`0``#X53____18G@3(GO12GX3(M\)`A$B40D
M'.@+TO__1(M$)!Q-`?</'P!!@_@_#XZE````08U`P(E$)!S!Z`9!B<2)1"0(
M28/$`4G!Y`9-`?QF#Q^$``````!)BP=,B>])@\=`2(F$)-@```!)BT?(2(F$
M).````!)BT?02(F$).@```!)BT?82(F$)/````!)BT?@2(F$)/@```!)BT?H
M2(F$)``!``!)BT?P2(F$)`@!``!)BT?X2(F$)!`!``#H9='__TTY_'60BT0D
M"$2+1"0<P>`&02G`2(M\)!!)8]"Y2````$R)_D2)1"0(Z._,__]$BT0D"$2)
MA"08`0``Z57^__\/'T0``$V)]^D8____#Q^$``````!(BXPDT````$B-<0'I
M;/[__XL\).AGS/__3(ND),@```!,B[0DT````$R)X$C!Z`.#X#^-4`%(F,:$
M!-@```"`@_HX#X^.`@``N#@````IT$ACTH/X"$F-5!4X#X.V`@``J`0/A6<#
M``"%P'0+J`+&`@`/A6L#``!,B?!,B>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-
MO"0A`0``B(0D$`$``$R)\$R-+;T)``!(P>@0B(0D$0$``$R)\$R-M"1H`0``
M2,'H"(B$)!(!``!,B>!(P>@8B(0D%`$``$R)X$C!Z!"(A"05`0``3(G@2,'H
M"(B$)!8!``#H%=#__TB+A"2@````2(G"B(0D(P$``$C!ZAA$#[;"B)0D(`$`
M`$B)PDC!ZA"(E"0A`0``2(G"2(N$)*@```!(P>H(B)0D(@$``$B)PHB$)"<!
M``!(P>H8B)0D)`$``$B)PDC!ZA"(E"0E`0``2(G"2(N$)+````!(P>H(B)0D
M)@$``$B)PHB$)"L!``!(P>H8B)0D*`$``$B)PDC!ZA"(E"0I`0``2(G"2(N$
M)+@```!(P>H(B)0D*@$``$B)PHB$)"\!``!(P>H8B)0D+`$``$B)PDC!ZA"(
ME"0M`0``2(G"2(N$),````!(P>H(B)0D+@$``$B)PHB$)#,!``!(P>H8B)0D
M,`$``$B)PDC!ZA"(E"0Q`0``2(G"2(V$)$`!``!(P>H(B)0D,@$``$B)!"1)
MB<3I"````$4/M@=)@\<!3(GG,<!,B>E(Q\+_____O@$```!)@\0"Z%/+__]-
M.>9UUDB-!5@(``#&A"1H`0```%#_="0(2(T-$`@``$R-#=0&``"^`0```$F)
MZ$C'PO____](B=\QP.@3R___65[I&?K__TV+;0A-A>T/A#?Y__],B>_HC\G_
M_TB#^`,/AB7Y__])C70%_$B-/;D'``"Y!0```/.F30]$Y>D)^?__N$````!(
M8\HIT$F-3`TXB<)T#S'`B<:#P`$YT,8$,0!R\TR)[^@/SO__28U5.+D'````
M,<!(B=?S2*OI8?W__XG!2,<"`````$C'1`KX`````$B-2@A(@^'X2"G*`="#
MX/B#^`@/@C;]__^#X/@QTHG6@\((.<)(QP0Q`````'+OZ1O]__^`O"1R`0``
M00^%3/K__X"\)',!``!##X4^^O__@+PD=`$``$@/A3#Z__^`O"1U`0``10^%
M(OK__T2+/"2Z`@```$C'QL;___]$B?_HV\G__[HI````3(GV1(G_Z//(__](
MC07U!@``4$%6Z:+^__\/'T``QP(`````QT0"_`````#IE?S__S'_9HE\`O[I
MB?S__^A4R/__9I!F+@\?A```````059!54%455-(@^P0BSTN72``9$B+!"4H
M````2(E$)`@QP$R-;"0$Z+3(__^+/0Y=(`!(B</HILC__P^V@+````!(C3TK
M!0``3(GNB(.Q````,<#H".3__TB%P'0)@#@Q#X2J`@``,<#H\^[__XL]S5P@
M`.AHR/__2(TU-`8``+D+````N@$```!(B<?H+\C__TB%P`^$MP```(,]#VT@
M``%(BT`03(M@*`^.H@```#'MNP$```#K,P\?A```````28MV$$B+!=UL(`!(
M8]-(BSS0Z.''__^%P'5EBP7/;"``@\,!@\4!.=A^6XL]3UP@`.CJQ___,<E(
M8]5,B>9(B<?H2LC__TB%P'0U3(LP08M&#"4`!"``/0`$``!THHL]'%P@`.BW
MQ___3(GVN0(````QTDB)Q^@UQ___2(G&ZX2+!6IL(`"-4/\YZ@^$?P$``(L]
MZ5L@`.B$Q___2(TU504``+D#````N@$```!(B<?H2\?__TB%P$B)PW0U2(M`
M$(L]N5L@`$B+*.A1Q___2(T5)`4``$B)QTB)[NC'QO__2(M#$$B+&/9##D`/
MA<H!``"+/8A;(`#H(\?__TB--?L#``"Y`P```+H!````2(G'Z.K&__](A<!(
MB<-T/4B-/5P#```QP$R)[NAQXO__2(7`2(G%#X15`0``2(M#$(L].UL@`$B+
M&.C3QO__2(GJ2(G'2(G>Z$W&__^+/1];(`#HNL;__TB--9($``"Z`0```$B)
MQ^BVQO__BST`6R``2(G#Z)C&__](C16%!```2(G>2(G'Z`[&__^+/>!:(`#H
M>\;__TB-/<P"``#&@+$`````3(GN,<#HX^'__TB%P$B)PTB)!2YK(``/A)``
M``"^P`$``$B)W^A3Q?__C5`!@_H!=@F#^!$/A>X```!(BT0D"&1(,P0E*```
M``^%U0```$B#Q!!;74%<05U!7L.0@_@!#XYX_O__NP$```!FD(L]6EH@`(/#
M`>CRQ?__3(GF2(G'Z`?%__\Y';%J(`!_W^E+_O__9BX/'X0``````(!X`0`/
MA%/]___I1_W__Y!(BSV!:B``Z'3P__](A<!(B<-(B05_:B``#X51____2(T]
M:@0``#'`Z*O%__\/'P!(BP51:B``BSWC62``2(LH2(M#$$B+&.ATQ?__2(GN
M2(G?Z(GF___IG_[__XL]OED@`.A9Q?__2(G>2(G'Z'[%___I&_[__^BLQ/__
MB<%(BP4#:B``2(T]+`0``$B)VDB+,#'`Z#_%__\/'X``````55-(B?U(@^P(
MZ*+J__\/M@B$R71.2(U0`4B)PP\?0`"`^2\/M@I(#T3:2(/"`83)=>XQP.B'
M[?__2(7M=!Z%P'0:@'T``'042(TU9P(``$B)W^B)Q?__2#G8=`Q(@\0(6UW#
M2(G#Z\I(@\0(2(GO6UWINN/__V8N#Q^$``````!(C07A6"``2(7`=`Q(BPCI
M/,3__P\?0``QR>DQQ/__D$%7059!B?]!54%43(TE9E0@`%5(C2UF5"``4TF)
M]DF)U4PIY4B#[`A(P?T#Z!?#__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!
M_Q3<2(/#`4@YW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L
M"$B#Q`C#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!
M4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!
M4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!
M5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X
M`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A
M8VME<CHZ5D524TE/3@`Q+C`S-@`M90`M+0!?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M
M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M
M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[
M4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?
M05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%
M3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L
M87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R
M;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE
M("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E
M96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@
M(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L
M("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D
M8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F
M<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T
M("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I
M9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME
M>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO
M<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D
M("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O
M('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^
M(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!
M4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^
M(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D
M:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C
M72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D
M9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S
M*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*
M8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN
M="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I
M("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R
M:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I
M9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*
M;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D
M9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F
M:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@
M>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F
M:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C
M;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E
M;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA
M;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N
M86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO
M9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R
M;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M(&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?
M8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY
M("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%
M04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*```````!&P,[Y````!L```"@
M@O__,`$``)"$__]@!@``P(;__P`!``#PA___6`$``$"?__^H`0```*#___@!
M``"`H/__*`(``-"B__]X`@``4*3__\`"``#@I/__X`(``+"E__\@`P``X*7_
M_S@#```PIO__4`,```"G__^``P``$*?__Y@#```@J?__^`,``%"I__\0!```
M0*K__V`$``!@K/__B`0``."L__^H!```$*W__\@$``"`KO__*`4``."Z___@
M!0``H+[__R@&```@O___D`8``$"___^H!@``L+____`&````````%```````
M```!>E(``7@0`1L,!PB0`0<0%````!P```"XA?__*P``````````````%```
M```````!>E(``7@0`1L,!PB0`0``)````!P```!H@?__$``````.$$8.&$H/
M"W<(@``_&CLJ,R0B`````$P```!$````D(;__T87````0@X0CP)"#AB.`T8.
M((T$0@XHC`5##C"&!D$..(,'1P[0!0,?%PH..$$.,$$.*$(.($(.&$(.$$(.
M"$$+````3````)0```"0G?__O@````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=$#D`"?`H..$0.,$$.*$(.($(.&$(.$$(."$D+```````L````
MY`````">__]^`````$$.$(8"00X8@P-'#C`";0H.&$$.$$$."$$+``````!,
M````%`$``%">__])`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+`````$0```!D`0``4*#_
M_WP!````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH00X@
M0@X80@X00@X(2PL``````!P```"L`0``B*'__X$`````00X0@P)I"@X(1@L"
M4`X(/````,P!``#XH?__T`````!"#A"-`D(.&(P#1`X@A@1!#BB#!58.P"`"
M?`H.*$$.($$.&$(.$$(."$<+`````!0````,`@``B*+__S``````1`X09PX(
M`!0````D`@``H*+__TD`````1`X0?0X(`"P````\`@``V*+__\$`````00X0
MA@)!#AB#`T<.P$`"J`H.&$$.$$$."$4+`````!0```!L`@``>*/__P4`````
M`````````%P```"$`@``<*/__PD"````0@X0CP)"#AB.`T(.((T$0@XHC`5$
M#C"&!D$..(,'40[@(`)D"@XX00XP00XH0@X@0@X80@X00@X(00L"F0[H($\.
M\"!Y#N@@00[@(````!0```#D`@``(*7__R0``````````````$P```#\`@``
M.*7__^,`````00X0A@)!#AB#`T0.(`)U"@X800X000X(0PMY"@X82`X000X(
M1@M$"@X80PX000X(00M$#AA(#A!!#@@`````)````$P#``#8I?__$@(```!!
M#A"#`DL.4`.>`0H.$$$."$4+`````!P```!T`P``T*?__WD`````1`X@;PH.
M"$4+````````'````)0#```PJ/__)`````!$#A!8"@X(1`L```````!<````
MM`,``$"H__]L`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!U(.
MH`$"QPH..$$.,$$.*$(.($(.&$(.$$(."$@+:`ZH`5`.L`%Q#J@!00Z@`0``
M``"T````%`0``%"I__]4#````$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!
M#CB#!TX.P(,"`R@"#LB#`E(.T(,":`[(@P)"#L"#`@)T"@XX00XP00XH0@X@
M0@X80@X00@X(0PL#B@$.R(,"2`[0@P)A#LB#`D$.P(,"8P[(@P))#M"#`D(.
MV(,"1`[@@P)=#L"#`@/'!0[(@P)$#M"#`F@.R(,"00[`@P(#+@$*#LB#`D(.
MT(,"20L`1````,P$``#XM/__N0,```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.
M,(,&1`Y``[H""@XP00XH00X@0@X80@X00@X(0@L`````-````!0%``!PN/__
M=@````!!#A"&`D$.&(,#1PX@`E<*#AA!#A!!#@A!"TD.&$0.$$$."``````L
M````3`4``"A^__\D`@```$$.$(8"00X8@P-$#E`#M`$*#AA!#A!!#@A!"P``
M```4````?`4``(BX__\?``````````````!$````E`4``)"X__]E`````$(.
M$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.($(.
M&$(.$$(."``4````W`4``+BX__\"````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````,`?````
M````@!\```````````````````````````````````````````````````$`
M`````````0`````````!`````````-\!`````````0`````````N`@``````
M``P`````````B!H````````-`````````+17````````&0````````"XJR``
M`````!L`````````"``````````:`````````,"K(```````'``````````(
M`````````/7^_V\`````F`(````````%`````````"`-````````!@``````
M``"0`P````````H`````````WP0````````+`````````!@`````````%0``
M``````````````````,`````````R*T@```````'`````````%`3````````
M"``````````X!P````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````T!(```````#___]O``````(`
M````````\/__;P``````$@```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````.BK(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P``````6P```````$=#
M0SH@*%5B=6YT=2`V+C,N,"TR=6)U;G1U,2D@-BXS+C`@,C`Q-C$R,CD`1T-#
M.B`H56)U;G1U(#8N,BXQ+35U8G5N='4R*2`V+C(N,2`R,#$V,3(P,@``+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YI;FET`"YP;'0`+G!L="YG;W0`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD871A+G)E;"YR;P`N9'EN86UI
M8P`N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M````````````````````````````````````````````````````````````
M``L````!`````@`````````X`@```````#@"````````'```````````````
M``````$````````````````````3````!P````(`````````5`(```````!4
M`@```````"`````````````````````$````````````````````(0````<`
M```"`````````'0"````````=`(````````D````````````````````!```
M`````````````````#0```#V__]O`@````````"8`@```````)@"````````
M^``````````%``````````@````````````````````^````"P````(`````
M````D`,```````"0`P```````)`)````````!@````$````(`````````!@`
M````````1@````,````"`````````"`-````````(`T```````#?!```````
M`````````````0```````````````````$X```#___]O`@``````````$@``
M```````2````````S``````````%``````````(``````````@````````!;
M````_O__;P(`````````T!(```````#0$@```````(``````````!@````(`
M```(````````````````````:@````0````"`````````%`3````````4!,`
M```````X!P````````4`````````"``````````8`````````'0````!````
M!@````````"(&@```````(@:````````%P````````````````````0`````
M``````````````!Z`````0````8`````````H!H```````"@&@```````!``
M```````````````````0`````````!``````````?P````$````&````````
M`+`:````````L!H```````#@`0``````````````````"```````````````
M`````(@````!````!@````````"0'````````)`<````````(CL`````````
M`````````!````````````````````".`````0````8`````````M%<`````
M``"T5P````````D````````````````````$````````````````````E```
M``$````"`````````,!7````````P%<```````!`0```````````````````
M"````````````````````)P````!`````@``````````F`````````"8````
M````Y`````````````````````0```````````````````"J`````0````(`
M````````Z)@```````#HF````````"0&```````````````````(````````
M````````````M`````X````#`````````+BK(```````N*L````````(````
M````````````````"``````````(`````````,`````/`````P````````#`
MJR```````,"K````````"`````````````````````@`````````"```````
M``#,`````0````,`````````R*L@``````#(JP````````@`````````````
M```````(````````````````````T0````$````#`````````-"K(```````
MT*L````````3````````````````````$````````````````````-X````&
M`````P````````#HJR```````.BK````````X`$````````&``````````@`
M````````$`````````"#`````0````,`````````R*T@``````#(K0``````
M`#@"```````````````````(``````````@`````````YP````$````#````
M``````"P(````````+`````````@````````````````````"```````````
M`````````.T````(`````P`````````@L"```````""P````````B!``````
M`````````````"````````````````````#R`````0```#``````````````
M```````@L````````%@````````````````````!``````````$`````````
M`0````,`````````````````````````>+````````#[````````````````
3`````0``````````````````````
